"use strict";

const debug = require('debug')('project3:app.js');
const express = require('express');
const logger = require('morgan');
const path = require('path');
const session = require('express-session');
const MongoDBStore = require('connect-mongodb-session')(session);

require("dotenv").config();

// check that all three db variables are set in .env
if (!(process.env.DB_HOST && process.env.DB_PASS && process.env.DB_USER)) {
    console.error("Missing environment variables for Host, Password, and User");
    process.exit(1);
}

const { initDb } = require('./models/db');

initDb().then(() => {
    const apiRouter = require('./routes/api');

    const app = express();

    // Create a connection for MongoDB storage of sessions
    const store = new MongoDBStore({
        uri: `mongodb+srv://${process.env.DB_USER}:${process.env.DB_PASS}@${process.env.DB_HOST}/Project3?retryWrites=true&w=majority`,
        collection: 'sessions'
    });

    store.on('error', (err) => {
        console.error(err);
    });

    // secret for cookies
    const secret = "SLU CS332 F21";
    var sess = {
        secret: secret,
        cookie: {},
        store: store
    };

    // better handling of cookies for production deployments
    if (app.get('env') === 'production') {
        app.set('trust proxy', 1) // trust first proxy
        sess.cookie.secure = true // serve secure cookies
    }

    // view engine setup
    app.set('views', path.join(__dirname, 'views'));
    app.set('view engine', 'ejs');

    app.use(logger('dev'));
    app.use(express.json());
    app.use(session(sess));
    app.use(express.static(path.join(__dirname, 'public')));

    // set up the api middleware (see routes)
    app.use('/api', apiRouter);

    const port = 3000;
    const server = app.listen(port);
    server.on('error', onError);
    server.on('listening', onListening);

    /**
     * Event listener for HTTP server "error" event.
     */

    function onError(error) {
        if (error.syscall !== 'listen') {
            throw error;
        }

        var bind = typeof port === 'string'
            ? 'Pipe ' + port
            : 'Port ' + port;

        // handle specific listen errors with friendly messages
        switch (error.code) {
            case 'EACCES':
                console.error(bind + ' requires elevated privileges');
                process.exit(1);
                break;
            case 'EADDRINUSE':
                console.error(bind + ' is already in use');
                process.exit(1);
                break;
            default:
                throw error;
        }
    };

    /**
     * Event listener for HTTP server "listening" event.
     */

    function onListening() {
        var addr = server.address();
        var bind = typeof addr === 'string'
            ? 'pipe ' + addr
            : 'port ' + addr.port;
        debug('Listening on ' + bind);
    };
});






