"use strict";

// Module to connect to the MongoDB instance
const { MongoClient } = require("mongodb");

// fancy debug output package (everything will be prefixed with "project3:db")
const debug = require("debug")("project3:db");

// connection URL
const url = `mongodb+srv://${process.env.DB_USER}:${process.env.DB_PASS}@${process.env.DB_HOST}/Project3?retryWrites=true&w=majority`;

// represent the client
let _client;

// Two interface functions: initialize DB connection, get the database client

module.exports.initDb = async () => {
    // error checking
    if (_client) {
        // give a warning and just return the client
        debug("Trying to init the DB again!");
        return _client;
    }

    _client = new MongoClient(url);

    await _client.connect();
    debug("Connected to MongoDB");
    return _client;
};

module.exports.getDb = () => {
    if (!_client) {
        debug("Tried to access client before connecting");
        throw "Db has not been initialized.  Please call init first.";
    }

    return _client;
};
